@@ -62,8 +62,8 @@ struct Index2PVolumeConverter {
 #ifdef VECCORE_CUDA_DEVICE_COMPILATION
     // checking here for NVCC_DEVICE since the global variable globaldevicegeomgata::gCompact...
     // is marked __device__ and can only be compiled within device compiler passes
-    assert(vecgeom::globaldevicegeomdata::GetCompactPlacedVolBuffer() != nullptr);
-    return &vecgeom::globaldevicegeomdata::GetCompactPlacedVolBuffer()[index];
+    assert(vecgeom::globaldevicegeomdata::gCompactPlacedVolBuffer != nullptr);
+    return &vecgeom::globaldevicegeomdata::gCompactPlacedVolBuffer[index];
 #else
 #ifndef VECCORE_CUDA
     assert(vecgeom::GeoManager::gCompactPlacedVolBuffer == nullptr ||
@@ -652,7 +652,7 @@ void NavStatePath::Dump() const
   const unsigned int *ptr = (const unsigned int *)this;
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-qual"
-  printf("NavState::Dump(): data: %p(%lu) : %p(%lu) : %p(%lu)\n", (void *)&fCurrentLevel, sizeof(fCurrentLevel),
+  printf("NavState::Dump(): data: %p(%zu) : %p(%zu) : %p(%zu)\n", (void *)&fCurrentLevel, sizeof(fCurrentLevel),
          (void *)&fOnBoundary, sizeof(fOnBoundary), (void *)&fPath, sizeof(fPath));
   for (unsigned int i = 0; i < 20; ++i) {
     printf("%p: ", (void *)ptr);
