@@ -293,13 +293,6 @@ public:
                                                                               points, output);
   }
 
-  virtual void SafetyToInMinimize(SOA3D<Precision> const & /* points */, Precision *const /* safeties */) const override
-  {
-    throw std::runtime_error("SafetyToInMinimize unimplemented");
-    // we do no longer need this (probably)
-    // SafetyToInMinimizeTemplate(points, safeties);
-  }
-
   virtual void DistanceToIn(SOA3D<Precision> const &points, SOA3D<Precision> const &directions,
                             Precision const *const stepMax, Precision *const output) const override
   {
@@ -409,7 +402,6 @@ public:
 
     ConstructManyOnGpu<CudaType_t<ThisClass_t>>(in_gpu_ptrs.size(), in_gpu_ptrs.data(), logical_volumes.data(),
                                                 transforms.data(), ids.data(), copyNos.data(), childIds.data());
-    CudaCheckError();
   }
 
 #endif // VECGEOM_CUDA_INTERFACE
@@ -444,13 +436,6 @@ public:
                                                                                        points.size(), points, output);
   }
 
-  virtual void SafetyToInMinimize(SOA3D<Precision> const &points, Precision *const safeties) const override
-  {
-    (void)points;
-    (void)safeties;
-    throw std::runtime_error("SafetyToInMinimize unimplemented");
-  }
-
   virtual void Contains(SOA3D<Precision> const &points, bool *const output) const override
   {
     auto unplacedv = this->GetUnplacedStruct();
@@ -556,7 +541,6 @@ public:
 
     ConstructManyOnGpu<CudaType_t<ThisClass_t>>(in_gpu_ptrs.size(), in_gpu_ptrs.data(), logical_volumes.data(),
                                                 transforms.data(), ids.data(), copyNos.data(), childIds.data());
-    CudaCheckError();
   }
 #endif // VECGEOM_CUDA_INTERFACE
 
